import { colors } from '@/components/ui';
import defaultColors from 'tailwindcss/colors';
import * as React from 'react'
import { ActivityIndicator, Pressable, Text, View, ViewStyle } from 'react-native';

// 색상 처리 유틸 함수
const getColor = (colorValue: string) => {
  // HEX, RGB, RGBA 형식이면 그대로 반환
  if (colorValue.startsWith('#') || colorValue.startsWith('rgb')) {
    return colorValue;
  }
  
  // brand-primary-default 같은 중첩된 경로 처리
  const paths = colorValue.split('-');
  if (paths.length > 2) {
    // @ts-ignore
    let result = colors;
    for (const path of paths) {
      // @ts-ignore
      result = result[path];
      if (!result) break;
    }
    if (result) return result;
  }
  
  // neutral-400, primary-500 같은 기존 형식 처리
  const [category, shade] = colorValue.split('-');
  
  // @ts-ignore
  if (colors[category] && colors[category][shade]) {
    // @ts-ignore
    return colors[category][shade];
  }
  
  // Tailwind 기본 컬러에서 확인
  // @ts-ignore
  if (defaultColors[category]?.[shade]) {
    // @ts-ignore
    return defaultColors[category][shade];
  }
  
  // white, black 같은 단일 색상 처리
  // @ts-ignore
  if (colors[colorValue]) {
    // @ts-ignore
    return colors[colorValue];
  }
  
  return colorValue;
}

interface IconProps {
  icon: React.ReactNode;
  gap?: string | number;
}
interface BorderInterface {
  borderWidth: string;
  borderColor: string;
}

interface CommonPrimeButtonProps {
  text?: string;
  textColor?: string;
  backgroundColor?: string;
  width?: string;
  height?: string;
  radius?: string;
  loading?: boolean;
  disabled?: boolean;
  border?: BorderInterface;
  leftIcon?: IconProps;
  rightIcon?: IconProps;
  className?: string;
  style?: ViewStyle;
  onPress?: () => void;
}

export default function CommonPrimeButton({
  loading = false,
  text = 'default',
  textColor = 'white',
  backgroundColor = 'black',
  width = 'w-[138px]',
  height = 'h-14',
  radius = 'rounded-2xl',
  disabled = false,
  border = { borderWidth: '0', borderColor: 'transparent' },
  onPress,
  leftIcon,
  rightIcon,
  className,
  style,
}: CommonPrimeButtonProps) {
  const getMarginStyle = (gap?: string | number, isLeft: boolean = true) => {
    if (!gap) return {};
    if (typeof gap === 'number') {
      return isLeft ? { marginRight: gap } : { marginLeft: gap };
    }
    return { className: gap };  // string인 경우 className으로 반환
  }

  return (
    <Pressable 
      className={`
        flex-row items-center justify-center
        ${width} ${height} ${radius}
        ${disabled ? 'opacity-50' : ''}
        ${className || ''}  
      `}
      style={[
        {
          backgroundColor: getColor(backgroundColor),
          borderWidth: Number(border.borderWidth),
          borderColor: getColor(border.borderColor),
        },
        !className && style  // className이 없을 때만 style 적용
      ]}
      onPress={onPress}
      disabled={disabled || loading}
    >
      {loading ? (
        <ActivityIndicator
          size="small"
          color={getColor(textColor)}
        />
      ) : (
        <View className="flex-row items-center justify-center">
          {leftIcon && (
            <View {...getMarginStyle(leftIcon.gap, true)}>
              {leftIcon.icon}
            </View>
        )}
        
        <Text
          className="text-center font-medium"
          style={{ color: getColor(textColor) }}
        >
          {text}
        </Text>

        {rightIcon && (
          <View {...getMarginStyle(rightIcon.gap, false)}>
            {rightIcon.icon}
          </View>
          )}
        </View>
      )}
    </Pressable>
  );
}